@@ -1,21 +1,8 @@
 /*
-   This file is part of the KDE games lskat program
-   Copyright (c) 2006 Martin Heni <kde@heni-online.de>
+    This file is part of the KDE games lskat program
+    SPDX-FileCopyrightText: 2006 Martin Heni <kde@heni-online.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef THEME_MANAGER_H
@@ -26,8 +13,8 @@
 #include <QHash>
 #include <QSvgRenderer>
 
-// KDE includes
-#include <kconfig.h>
+// KF includes
+#include <KConfig>
 
 class KCardCache;
 class ThemeManager;
@@ -268,7 +255,7 @@ protected:
      */
     void updateCardTheme(const QString &themefile, const QString &cardTheme);
 
-private slots:
+private Q_SLOTS:
     void loadCardsInBackground();
 
 private:
